@@ -53,7 +53,7 @@ arma::mat vecMinusMats(const arma::mat &genotype, const int index)
 SEXP ohg(SEXP geno, SEXP threads)
 {
 
-	int t = as<int> (threads);
+//  int t = as<int> (threads);
 	NumericMatrix genotype(geno);
 	int n = genotype.nrow(), k = genotype.ncol();
 	arma::mat Genotype(as<arma::mat>(genotype).begin(), n, k, TRUE);
@@ -62,7 +62,7 @@ SEXP ohg(SEXP geno, SEXP threads)
 	arma::mat res2 = arma::zeros<arma::mat>(genotype.nrow(), genotype.nrow());
 	// make_nas(Genotype);
 
-	#pragma omp parallel for private(res2) schedule(dynamic)  num_threads(t)
+	#pragma omp parallel for private(res2) schedule(dynamic)  num_threads(as<int> (threads))
 	for (int i = 0; i < genotype.nrow(); i++)
 	{
 	//	Rprintf("%d\n", i);
